%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Classe desenvolvida para o ERMAC 2023 %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{ermacrs2023}
\typeout{Carregando a classe ERMAC 2023.}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Carrega a classe padrão de artigo %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\LoadClass[a4paper, twoside]{article}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Pacotes necessários para o adequado funcionamento da classe %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\RequirePackage{titlesec} % personalisar as seções
\RequirePackage{amsmath,amssymb,amsthm} % pacotes matemáticos básicos
\RequirePackage{graphicx} % básico para figura
\RequirePackage{indentfirst} % indenta sempre o primeiro parágrafo
\RequirePackage{xcolor} % para definir cores
\RequirePackage{makerobust} % define \MakeUppercase entre outros
\RequirePackage{geometry} % Margens
\RequirePackage{icomma} % corrige espaçamento quando vírgula é utilizada como separador decimal
\RequirePackage{booktabs} % melhorar exemplo de tabela
\RequirePackage{tabularx} % tabelas
\RequirePackage{multirow}
\RequirePackage{fancyhdr} % Cabeçalhos
\RequirePackage{natbib} % \citep, \citeyear, etc
\RequirePackage{caption} % para definir a fonte e alinhamento das legendas
\RequirePackage[brazil]{babel}
\RequirePackage{hyperref}
\RequirePackage{etoolbox}
\RequirePackage{enumitem}
\RequirePackage{float}


%%%%%%%%%%%%%%%%%%%%%%%%%
% Coleta de informações %
%%%%%%%%%%%%%%%%%%%%%%%%%

% Autor(es)
% \renewcommand{\author}[2]{
%   \authorName{#1}
%   \authorShort{#2}
% }

\renewcommand{\author}[1]{
  \authorName{#1}
}

\def\@authorName{O nome de ao menos um autor é necessário!}
\newcommand{\authorName}[1]{
  \def\@authorName{#1}
}

% \def\@authorShort{}
% \newcommand{\authorShort}[1]{
%   \def\@authorShort{#1}
% }

% Informações do(s) autor(es)
\def\@info{É necessário informar a filiação e e-mail dos autores!}
\newcommand{\info}[1]{
  \def\@info{#1}
}

% Título
\renewcommand{\title}[1]{
  \fullTitle{#1}
}

% \renewcommand{\title}[2]{
%  \fullTitle{#1}
%  \shortTitle{#2}
% }

\def\@fullTitle{Um título é necessário.}
\newcommand{\fullTitle}[1]{
  \def\@fullTitle{#1}
}

\def\@shortTitle{}
\newcommand{\shortTitle}[1]{
  \def\@shortTitle{#1}
}

% Resumo
\renewcommand{\abstract}[1]{
  \abstractContent{#1}
}

\def\@abstractName{Resumo:}
\newcommand{\abstractName}[1]{
  \def\@abstractName{#1}
}

\def\@abstractContent{O resumo é obrigatório.}
\newcommand{\abstractContent}[1]{
  \def\@abstractContent{#1}
}

% Palavras-chave
\newcommand{\keywords}[1]{
  \keywordsContent{#1}
}

\def\@keywordsName{Palavras-chave:}
\newcommand{\keywordsName}[1]{
  \def\@keywordsName{#1}
}

\def\@keywordsContent{Uma lista de palavras-chave é obrigatória!}
\newcommand{\keywordsContent}[1]{
  \def\@keywordsContent{#1}
}

%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Configurações da página %
%%%%%%%%%%%%%%%%%%%%%%%%%%%
\newgeometry{
  bottom = 2.5cm,
  top = 2.5cm,
  left = 3.0cm,
  right = 3.0cm,
  headheight = 27pt
}
\linespread{1.5} % equivale ao entrelinhas de 1.5 do word!
\setlength{\parindent}{1.0cm} % Tamanho da indentação do parágrafo.
\AtBeginEnvironment{thebibliography}{
\linespread{1}
\selectfont
\setlength{\bibsep}{12pt}
}
\setlist{nosep}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Fontes, tamanhos, enumerações, legendas, cores e links %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Tamanhos das fontes
\renewcommand{\scriptsize}{\fontsize{8}{8.5pt}\selectfont}
\renewcommand{\footnotesize}{\fontsize{9}{9pt}\selectfont}
\renewcommand{\small}{\fontsize{10}{11pt}\selectfont}
\renewcommand{\normalsize}{\fontsize{12}{12.5pt}\selectfont}
\renewcommand{\large}{\fontsize{14}{14.5pt}\selectfont}

% Configura legendas.
\captionsetup{
  font=small,
  labelfont=bf, 
  singlelinecheck=false,
  labelsep=period,
  skip=0.0\baselineskip
}

% Define as cores e aplica a corBase ao documento
\definecolor{corDestaque}{rgb}{0.0, 0.0, 0.0} % preto puro
\definecolor{corBase}{rgb}{0.2, 0.2, 0.2} % cinza quase preto - cansa menos o leitor
\AtBeginDocument{\color{corBase}} % estabelece a cor como padrão para o documento

% Configura os links
\hypersetup{
  colorlinks=true,
  linkcolor=corBase,
  filecolor=corBase,
  urlcolor=corBase,
  citecolor=corBase,
  pdfstartview={FitH}
}

% \AtBeginDocument{
%   \hypersetup{
%     pdftitle={\@fullTitle},
%     pdfauthor={\@authorName},
%     % pdfauthor={\@authorShort},
%     pdfsubject={ERMAC-RS 2023},
%     pdfkeywords={\@keywordsContent}
%   }
% }

% Define que equações não referenciadas não sejam numeradas
%\mathtoolsset{showonlyrefs=true}

%%%%%%%%%%
% Seções %
%%%%%%%%%%

% Configura a exibição das seções.
\titleformat{\section}[block]{\bf\raggedright\normalsize}{\thesection.}{1em}{\color{corDestaque}\MakeUppercase}[]
\titlespacing*{\section}{0pt}{2em}{1em}[0pt]

% Configura a exibição das subseções.
\titleformat{\subsection}[block]{\bf\raggedright\normalsize}{\thesubsection.}{1em}{\color{corDestaque}}[]
\titlespacing*{\subsection}{0pt}{2em}{1em}[0pt]

% Configura a exibição das subsubseções.
\titleformat{\subsubsection}[block]{\it\raggedright\normalsize}{\thesubsubsection.}{1em}{\color{corDestaque}}[]
\titlespacing*{\subsubsection}{0pt}{1em}{1em}[0pt]

% Configura a exibição dos parágrafos.
\renewcommand\paragraph{\@startsection{paragraph}{4}{\z@}%
      {3.25ex \@plus1ex \@minus.2ex}%
      {-1em}%
      {\normalfont\normalsize\bfseries\SS@parafont}}

% Configura a exibição dos subparágrafos.      
\renewcommand\subparagraph{\@startsection{subparagraph}{5}{\parindent}%
      {3.25ex \@plus1ex \@minus .2ex}%
      {-1em}%
      {\normalfont\normalsize\bfseries\SS@subparafont}}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Ambientes para teoremas, proposições, etc. %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\newtheorem{theorem}{Theorem}[section]
\newtheorem{lemma}{Lemma}[section]
\newtheorem{proposition}{Proposition}[section]
\newtheorem{definition}{Definition}[section]
\newtheorem{remark}{Remark}[section]
\newtheorem{corollary}{Corollary}[section]
\newtheorem{teorema}{Teorema}[section]
\newtheorem{lema}{Lema}[section]
\newtheorem{prop}{Proposi\c{c}\~ao}[section]
\newtheorem{defi}{Defini\c{c}\~ao}[section]
\newtheorem{obs}{Observa\c{c}\~ao}[section]
\newtheorem{cor}{Corol\'ario}[section]
\DeclareMathOperator{\sen}{sen}
\DeclareMathOperator{\arcsen}{arcsen}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Configurações dos cabeçalhos e rodapés %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\pagestyle{fancy}
\renewcommand{\headrulewidth}{0pt}
\fancyhead{}
\fancyfoot{}
\fancyfoot[R]{\thepage}

% Header da primeira página.
\fancypagestyle{empty}{%
 \renewcommand{\headrulewidth}{0pt}%
 \fancyhf{}%
 \fancyhead[L]{\footnotesize{\color{corBase}\emph{XI ERMAC-RS \\ Encontro Regional de Matem\'{a}tica Aplicada e Computacional do Rio Grande do Sul \\ Pelotas, 28 a 30 de junho de 2023}}}%
 % \fancyhead[R]{\thepage}
 \fancyfoot[R]{\thepage}
  % \renewcommand{\footrulewidth}{0.5pt}%
  % \fancyfoot[L]{\footnotesize\color{corBase} \@info}
}

% Header das páginas subsequentes.
\fancyhf{}
\renewcommand{\headrulewidth}{0pt}
\renewcommand{\footrulewidth}{0pt}
% \fancyhead[CE]{{\color{corBase} \scriptsize \@authorShort}}
\fancyhead[CE]{{\color{corBase} \scriptsize XI ERMAC--RS, Pelotas - 28 a 30 de junho de 2023}}
% \fancyhead[CO]{{\color{corBase} \scriptsize \@shortTitle}}
\fancyhead[CO]{{\color{corBase} \scriptsize XI ERMAC--RS, Pelotas - 28 a 30 de junho de 2023}}
\rfoot{\thepage}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Impressão de título, nomes, filiação, e-mail, resumo e palavras chave %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\def\maketitle{%
  \linespread{1.0}
  \newpage\thispagestyle{empty}
  \null
  \vskip 0em%
  \begin{center}%
    \let \footnote \thanks
    {\large \bf \color{corDestaque}{\MakeUppercase\@fullTitle} \par}%
  \end{center}%
  \vskip 1.5em%
  {\normalsize
    \lineskip .5em%
    \begin{minipage}[b]{\textwidth}
      \centering\@authorName
    \end{minipage}\par}%
  {\small\it
    \lineskip 1.5em%
    \begin{minipage}[b]{\textwidth}
      \centering\@info
    \end{minipage}\par}%
  \vskip 1em%
  {\small
    \lineskip .5em%
    \centering
    \begin{minipage}[b]{0.9\textwidth}
      {\color{corDestaque}{\textbf{\MakeUppercase\@abstractName} }}\@abstractContent
      \par\vskip 1em
      {\color{corDestaque}{\textbf{\@keywordsName} }}\@keywordsContent
    \end{minipage}\par}%
  \par
  \vskip 1em}